############################### 
#setting up dataset and packges
###############################

library(lattice)
library(ggplot2)
require(sciplot)
require(ggpubr)
## datasets
OT_data <- read.table("OT_data_matched_samples.csv")
OT_all<- read.table("OT_data_all.csv")

#### Main text Figures-------


## Figure 1
## Fig.1a: Baseline OT and cooperation

ggplot(OT_data, aes(x= baseline_OT, y=cooperation_binary,color=group,  shape=group)) +
  geom_jitter(position = position_jitter(width = 0.5, height = 0.1), size=2) +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+
  xlab(expression(paste("Baseline OT pg ", mL^{-1})))+ylab("Costly helping")+
  geom_smooth(method="glm",method.args = list(family = "binomial"),
              formula=y~x,  se=T) + theme_classic()+ theme_classic()+
  theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
        axis.ticks.length=unit(0.15, "cm"), 
        axis.text.x=element_text(margin=margin(10)),
        axis.text.y=element_text(margin=margin(r=10)))



## Fig 1b: change in OT and cooperation

lineplot.CI(cooperation_binary,change_OT, group =group , data = OT_data, cex = 1.5,
            xlab = "Costly helping",ylim=c(-8, 4), ylab = expression(paste("Change in OT pg ", mL^{-1})), 
            cex.axis=0.8,cex.lab = 0.9,cex.leg=0.7, x.leg = 1.4, y.leg=4.5,
            col = c("black","red"), pch = c(16,16),fixed=T)


## Figure 2

## Fig. 2a: Baseline OT and shared intentionality talk

plot1 <- ggplot(subset(OT_data, talk_condition=="talk"), aes(x= baseline_OT, y=shared_intentionality_prop,color=group,  shape=group)) + 
  geom_point(size=2)   +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+ 
  ylab("Proportion of \n shared intentionality talk")+xlab(expression(paste("Baseline OT pg ", mL^{-1})))+
  geom_smooth(method=lm, se=T)+ coord_cartesian(ylim=c(0,1),xlim=c(0,22))+
  theme_classic()+ theme_classic()+
  theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
        axis.ticks.length=unit(0.15, "cm"), 
        axis.text.x=element_text(margin=margin(10)),
        axis.text.y=element_text(margin=margin(r=10)))

## Fig. 2b: Baseline OT and goal talk

plot2 <- ggplot(subset(OT_data, talk_condition=="talk"), aes(x= baseline_OT, y=goal_talk_prop,color=group,  shape=group)) + 
  geom_point(size=2)  +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+ 
  ylab("Proportion of \n individual goal talk")+xlab(expression(paste("Baseline OT pg ", mL^{-1})))+
  geom_smooth(method=lm, se=T, fullrange=F)+ coord_cartesian(ylim=c(0,1),xlim=c(0,22))+
  theme_classic()+ theme_classic()+
  theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
        axis.ticks.length=unit(0.15, "cm"), 
        axis.text.x=element_text(margin=margin(10)),
        axis.text.y=element_text(margin=margin(r=10)))

## Fig. 2c: Baseline OT and task talk

plot3 <- ggplot(subset(OT_data, talk_condition=="talk"), aes(x= baseline_OT,  y=task_talk_prop,color=group,  shape=group)) + 
  geom_point(size=2)  +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+ 
  ylab("Proportion of \n task talk")+xlab(expression(paste("Baseline OT pg ", mL^{-1})))+
  geom_smooth(method=lm, se=T, fullrange=F)+ coord_cartesian(ylim=c(0,1),xlim=c(0,22))+
  theme_classic()+ theme_classic()+
  theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
        axis.ticks.length=unit(0.15, "cm"), 
        axis.text.x=element_text(margin=margin(10)),
        axis.text.y=element_text(margin=margin(r=10)))

## Fig. 2d: Baseline OT and other talk

plot4 <- ggplot(subset(OT_data, talk_condition=="talk"), aes(x= baseline_OT, y=other_talk_prop,color=group,  shape=group)) + 
  geom_point(size=2)  +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+ 
  ylab("Proportion of \n other talk")+xlab(expression(paste("Baseline OT pg ", mL^{-1})))+
  geom_smooth(method=lm, se=T, fullrange=F)+ coord_cartesian(ylim=c(0,1),xlim=c(0,22))+
  theme_classic()+ theme_classic()+
  theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
        axis.ticks.length=unit(0.15, "cm"), 
        axis.text.x=element_text(margin=margin(10)),
        axis.text.y=element_text(margin=margin(r=10)))


ggarrange(plot1,plot2,plot3 , plot4,
          labels = c("(a)", "(b)", "(c)", "(d)"),
          ncol = 2, nrow = 2, heights=1, widths=1, align="hv",font.label = list(size = 10))

## Figure 3
## Fig 3a: changes in OT and shared intentionality talk

plot1 <- ggplot(subset(OT_data, talk_condition=="talk"), aes(y= change_OT, x=shared_intentionality_prop,color=group,  shape=group)) + 
  geom_point(size = 2)  +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+ 
  xlab("Proportion of \n shared intentionality talk")+ylab(expression(paste("Change in OT pg ", mL^{-1})))+
  geom_smooth(method=lm, se=T)+  coord_cartesian(ylim=c(-18,18),xlim=c(0, 1))+
  theme_classic()+theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
                        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
                        axis.ticks.length=unit(0.15, "cm"), 
                        axis.text.x=element_text(margin=margin(10)),
                        axis.text.y=element_text(margin=margin(r=10)))


## Fig 3b: changes in OT and individual goal talk

plot2 <- ggplot(subset(OT_data, talk_condition=="talk"), aes(y= change_OT, x=goal_talk_prop,color=group,  shape=group)) + 
  geom_point(size=2)   +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+ 
  xlab("Proportion of \n individual goal talk")+ylab(expression(paste("Change in OT pg ", mL^{-1})))+
  geom_smooth(method=lm, se=T)+ coord_cartesian(ylim=c(-18,18),xlim=c(0, 1))+
  theme_classic()+theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
                        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
                        axis.ticks.length=unit(0.15, "cm"), 
                        axis.text.x=element_text(margin=margin(10)),
                        axis.text.y=element_text(margin=margin(r=10)))


plot3 <- ggplot(subset(OT_data, talk_condition=="talk"), aes(y= change_OT, x=task_talk_prop,color=group,  shape=group)) + 
  geom_point(size = 2)  +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+ 
  xlab("Proportion of \n task talk")+ylab(expression(paste("Change in OT pg ", mL^{-1})))+
  geom_smooth(method=lm, se=T)+  coord_cartesian(ylim=c(-18,18),xlim=c(0, 1))+
  theme_classic()+theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
                        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
                        axis.ticks.length=unit(0.15, "cm"), 
                        axis.text.x=element_text(margin=margin(10)),
                        axis.text.y=element_text(margin=margin(r=10)))


plot4 <- ggplot(subset(OT_data, talk_condition=="talk"), aes(y= change_OT, x=other_talk_prop,color=group,  shape=group)) + 
  geom_point(size = 2)  +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+ 
  xlab("Proportion of \n other talk")+ylab(expression(paste("Change in OT pg ", mL^{-1})))+
  geom_smooth(method=lm, se=T)+  coord_cartesian(ylim=c(-18,18),xlim=c(0, 1))+
  theme_classic()+theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
                        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
                        axis.ticks.length=unit(0.15, "cm"), 
                        axis.text.x=element_text(margin=margin(10)),
                        axis.text.y=element_text(margin=margin(r=10)))

ggarrange(plot1,plot2,plot3 , plot4,
          labels = c("(a)", "(b)", "(c)", "(d)"),
          ncol = 2, nrow = 2, heights=1, widths=1, align="hv",font.label = list(size = 10))


### Supplementary Figures-------

# Fig. S4
## Fig.4a: Baseline OT and cooperation from all data

ggplot(subset(OT_all, order=="before"), aes(x= OT, y=cooperation_binary,color=group,  shape=group)) +
  geom_jitter(position = position_jitter(width = 0.5, height = 0.1), size=2) +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+
  xlab(expression(paste("Baseline OT pg ", mL^{-1})))+ylab("Costly helping")+
  geom_smooth(method="glm",method.args = list(family = "binomial"),
              formula=y~x,  se=T) + theme_classic()+ theme_classic()+
  theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
        axis.ticks.length=unit(0.15, "cm"), 
        axis.text.x=element_text(margin=margin(10)),
        axis.text.y=element_text(margin=margin(r=10)))


## Fig.S4b: Baseline OT and cooperation from matched samples data

ggplot(OT_data, aes(x= baseline_OT, y=cooperation_binary,color=group,  shape=group)) +
  geom_jitter(position = position_jitter(width = 0.5, height = 0.1), size=2) +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+
  xlab(expression(paste("Baseline OT pg ", mL^{-1})))+ylab("Costly helping")+
  geom_smooth(method="glm",method.args = list(family = "binomial"),
              formula=y~x,  se=T) + theme_classic()+ theme_classic()+
  theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
        axis.ticks.length=unit(0.15, "cm"), 
        axis.text.x=element_text(margin=margin(10)),
        axis.text.y=element_text(margin=margin(r=10)))


## Fig. S5: baseline OT and the four talk categories

## Fig. 5a: Baseline OT and shared intentionality talk

plot1 <- ggplot(subset(subset(OT_all, talk_condition=="talk"), order=="before"), aes(x= OT, y=shared_intentionality_prop,color=group,  shape=group)) + 
  geom_point(size=2)   +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+ 
  ylab("Proportion of \n shared intentionality talk")+xlab(expression(paste("Baseline OT pg ", mL^{-1})))+
  geom_smooth(method=lm, se=T)+ coord_cartesian(ylim=c(0,1),xlim=c(0,22))+
  theme_classic()+ theme_classic()+
  theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
        axis.ticks.length=unit(0.15, "cm"), 
        axis.text.x=element_text(margin=margin(10)),
        axis.text.y=element_text(margin=margin(r=10)))

## Fig. 5b: Baseline OT and goal talk

plot2 <- ggplot(subset(subset(OT_all, talk_condition=="talk"), order=="before"), aes(x= OT, y=goal_talk_prop,color=group,  shape=group)) + 
  geom_point(size=2)  +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+ 
  ylab("Proportion of \n individual goal talk")+xlab(expression(paste("Baseline OT pg ", mL^{-1})))+
  geom_smooth(method=lm, se=T, fullrange=F)+ coord_cartesian(ylim=c(0,1),xlim=c(0,22))+
  theme_classic()+ theme_classic()+
  theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
        axis.ticks.length=unit(0.15, "cm"), 
        axis.text.x=element_text(margin=margin(10)),
        axis.text.y=element_text(margin=margin(r=10)))

## Fig. 5c: Baseline OT and task talk

plot3 <- ggplot(subset(subset(OT_all, talk_condition=="talk"), order=="before"), aes(x= OT, y=task_talk_prop,color=group,  shape=group)) + 
  geom_point(size=2)  +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+ 
  ylab("Proportion of \n task talk")+xlab(expression(paste("Baseline OT pg ", mL^{-1})))+
  geom_smooth(method=lm, se=T, fullrange=F)+ coord_cartesian(ylim=c(0,1),xlim=c(0,22))+
  theme_classic()+ theme_classic()+
  theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
        axis.ticks.length=unit(0.15, "cm"), 
        axis.text.x=element_text(margin=margin(10)),
        axis.text.y=element_text(margin=margin(r=10)))

## Fig. 5d: Baseline OT and other talk

plot4 <- ggplot(subset(subset(OT_all, talk_condition=="talk"), order=="before"), aes(x= OT, y=other_talk_prop,color=group,  shape=group)) + 
  geom_point(size=2)  +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+ 
  ylab("Proportion of \n other talk")+xlab(expression(paste("Baseline OT pg ", mL^{-1})))+
  geom_smooth(method=lm, se=T, fullrange=F)+ coord_cartesian(ylim=c(0,1),xlim=c(0,22))+
  theme_classic()+ theme_classic()+
  theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
        axis.ticks.length=unit(0.15, "cm"), 
        axis.text.x=element_text(margin=margin(10)),
        axis.text.y=element_text(margin=margin(r=10)))

ggarrange(plot1,plot2,plot3 , plot4,
          labels = c("(a)", "(b)", "(c)", "(d)"),
          ncol = 2, nrow = 2, heights=1, widths=1, align="hv")




## Fig. S7:  Costly helping predicted by individual goal talk as a function of group membership
ggplot(subset(OT_data, talk_condition=="talk"), aes(y=cooperation_binary, x=goal_talk_prop)) + 
  geom_point(size=2, aes(colour=factor(group), shape=factor(group)))   +scale_colour_manual(name="",  values =c("InGroup"="black", "OutGroup"="red"))+ 
  xlab("Proportion of \n individual goal talk")+ylab("Costly helping")+
  geom_smooth(method=lm, se=T, formula=y~x, fullrange=FALSE)+ coord_cartesian(ylim=c(0,1),xlim=c(0, 0.5))+
  theme_classic()+theme(legend.position="none",panel.border = element_rect(fill = NA, size=0.7),
                        axis.line.x = element_line(color="black", size = 0),axis.line.y = element_line(color="black", size = 0),
                        axis.ticks.length=unit(0.15, "cm"), 
                        axis.text.x=element_text(margin=margin(10)),
                        axis.text.y=element_text(margin=margin(r=10)))


