############################### 
# setting up dataset and packges
###############################

library(car)
library(RVAideMemoire)
library(lattice)
library(nlme)
library(nortest)
library(effects)
library(MuMIn)
require(ggplot2)
require(multcomp)
require(lsmeans)
library(lmerTest)
library(gam)
install.packages("piecewiseSEM")

# datasets
OT_data <- read.table("OT_data_matched_samples.csv")
summary(OT_data)
head(OT_data)

## scaling the discrete explanatory variables
OT_data$sbaseline_OT <- scale(OT_data$baseline_OT)
OT_data$sshared_intentionality_prop <- scale(OT_data$shared_intentionality_prop)
OT_data$sgoal_talk_prop <- scale(OT_data$goal_talk_prop)
OT_data$sgoal_talk_prop <- scale(OT_data$goal_talk_prop)
OT_data$stask_talk_prop <- scale(OT_data$task_talk_prop)
OT_data$sother_talk_prop <- scale(OT_data$other_talk_prop)


xtabs(~ group + gender, OT_data)

############### initial OT and gender ###############
global.model <- lm(log(baseline_OT)~gender, na.action=na.exclude, data=OT_data)
Anova(global.model)


############### initial OT and group ###############
global.model <- lm(log(baseline_OT)~group, na.action=na.exclude, data=OT_data)
Anova(global.model)


###########################################
##### active helping as a binary response##
###########################################


############# baseline OT from matched samples ###############
xtabs(~cooperation_binary+group, data=OT_data)
xtabs(~experiment_ID+group, data=OT_data)
global.model <- glm(cooperation_binary ~ (group + gender)*sbaseline_OT+group:gender, 
                      data=OT_data, family=binomial)
global.model0 <- glm(cooperation_binary ~ 1, data=OT_data, family=binomial)

summary(global.model)
anova(global.model0, global.model, test="Chi")
Anova(global.model)
1-(43.607/61.513)



          # Model Check
          qqPlot(residuals(global.model, "deviance"), id.n=4) # ok 
          plot(residuals(global.model,  "deviance"))
          plot(residuals(global.model,  "deviance") ~ fitted(global.model)) # ok
          residualPlots(global.model) # ok



# plot effects
plot(effect("group:sbaseline_OT", global.model))


# bootstrap
betahat.boot <- Boot(global.model, R=999) # 199 bootstrap samples--too small to be useful
summary(betahat.boot)  # default summary
confint(betahat.boot)


################### Change in OT  #######################

qqp(OT_data$change_OT)

mns <- tapply(OT_data$change_OT, list(OT_data$cooperation_binary, OT_data$group, OT_data$gender), mean, na.rm=T)
vrs <- tapply(OT_data$change_OT, list(OT_data$cooperation_binary, OT_data$group, OT_data$gender), var,  na.rm=T)
xyplot(vrs~mns, type=c("p", "smooth")) # wow. this should be random variation around a horizontal line
boxcox(change_OT + 14.6 ~ (cooperation_binary + group + gender)^2, data=OT_data)

OT_data$cooperation_binary_factor <- as.factor(ifelse(OT_data$cooperation_binary ==  "0" , "no", "yes"))
OT_data$mix<- OT_data$cooperation_binary_factor:OT_data$group
OT_data$mix01 <- as.factor(ifelse(OT_data$mix ==  "no:InGroup" , "0", "1"))

global.model <- gls(change_OT ~ (group+gender)*cooperation_binary_factor, 
                       weights=varIdent(form=~1|mix01),
                       na.action=na.exclude, data=OT_data)
summary(global.model)
Anova(global.model, type="II")  
rsquared(global.model)



        # Model Check
        lillie.test(resid(global.model))
        qqPlot(resid(global.model))
        xyplot(resid(global.model, type="pearson")~fitted(global.model), type=c("p", "smooth"))  # ok!!
        bwplot(resid(global.model, type="pearson")~group, data=OT_data)
        bartlett.test(resid(global.model, type="pearson")~interaction(cooperation_binary,group), data=OT_data) # ok
        bwplot(resid(global.model, type="pearson")~interaction(cooperation_binary,group), data=OT_data)
        bartlett.test(resid(global.model, type="pearson")~interaction(cooperation_binary,gender), data=OT_data) # ok
        bwplot(resid(global.model, type="pearson")~interaction(cooperation_binary,gender), data=OT_data)



# post hoc analyses
plot(effect("group:cooperation_binary ", global.model))

##### post hoc analyses suggested by Radu
detach("package:lsmeans", unload=TRUE)# 'lsmeans' package should not be active !!!
require(contrast) 
## cooperation no: out vs ingroup
myDiff <- contrast(global.model, list(gender=levels(OT_data$gender), 
                                      cooperation_binary = "no",  group = "InGroup"), 
                   list(gender=levels(OT_data$gender), 
                        cooperation_binary = "no",  group = "OutGroup"), type="average")

print(myDiff, X = TRUE)

## cooperation yes: out vs ingroup
myDiff <- contrast(global.model, list(gender=levels(OT_data$gender), 
                                      cooperation_binary = "yes",  group = "InGroup"), 
                   list(gender=levels(OT_data$gender), 
                        cooperation_binary = "yes",  group = "OutGroup"), type="average")

print(myDiff, X = TRUE)


## Outgroup: cooperation yes vs no
myDiff <- contrast(global.model, list(gender=levels(OT_data$gender), 
                                      cooperation_binary = "no",  group = "OutGroup"), 
                   list(gender=levels(OT_data$gender), 
                        cooperation_binary = "yes",  group = "OutGroup"), type="average")

print(myDiff, X = TRUE)



## Ingroup: cooperation yes vs no
myDiff <- contrast(global.model, list(gender=levels(OT_data$gender), 
                                      cooperation_binary = "no",  group = "InGroup"), 
                   list(gender=levels(OT_data$gender), 
                        cooperation_binary = "yes",  group = "InGroup"), type="average")

print(myDiff, X = TRUE)

# P.adjust

p.adjust(c(0.0014, 0.4142, 0.1247, 0.1936 ), method="holm")
###[1] 0.0056 0.4142 0.3741 0.3872#### the outcome


##### comparisons of the contrasts to the null hypothesis of no change ==0

## cooperation no Outgroup vs the zero
myDiff <- contrast(global.model, list(gender=levels(OT_data$gender), 
                                      cooperation_binary = "no",  group = "OutGroup"), type="average")

print(myDiff, X = TRUE)

## cooperation yes Outgroup vs the zero
myDiff <- contrast(global.model, list(gender=levels(OT_data$gender), 
                                      cooperation_binary = "yes",  group = "OutGroup"), type="average")

print(myDiff, X = TRUE)

## cooperation no Ingroup vs the zero
myDiff <- contrast(global.model, list(gender=levels(OT_data$gender), 
                                      cooperation_binary = "no",  group = "InGroup"), type="average")

print(myDiff, X = TRUE)

## cooperation yes Ingroup vs the zero
myDiff <- contrast(global.model, list(gender=levels(OT_data$gender), 
                                      cooperation_binary = "yes",  group = "InGroup"), type="average")

print(myDiff, X = TRUE)

# P.adjust

p.adjust(c(0.005,  0.7673, 0.0844, 0.4026 ), method="holm")
###[1] 0.0200 0.8052 0.2532 0.8052#### the outcome



################################################################################
######################### Analyses for Talking    ##############################
################################################################################

### baseline OT levels ###

### shared intentionality
xtabs(~ group + gender, subset(OT_data, talk_condition=="talk"))
xyplot(asin(sqrt(shared_intentionality_prop)) ~ sbaseline_OT|group:gender, type=c("p", "smooth"), data=subset(OT_data, talk_condition=="talk"))

global.model <- lm(asin(sqrt(shared_intentionality_prop)) ~ (group + gender) * sbaseline_OT +  I(sbaseline_OT^2),
                   data=subset(OT_data, talk_condition=="talk")) 
summary(global.model)
Anova(global.model, type="II")


        # Model Check
        qqPlot(global.model)
        lillie.test(stdres(global.model))
        xyplot(resid(global.model)~fitted(global.model), type=c("p", "smooth"))  # approx ok!! 
        xyplot(resid(global.model)~subset(OT_data, talk_condition=="talk")$sbaseline_OT , type=c("p", "smooth")) # ok
        residualPlots(global.model) #  ok

        # bootstrap
        betahat.boot <- Boot(global.model, R=999) # 199 bootstrap samples--too small to be useful
        summary(betahat.boot)  # default summary
        confint(betahat.boot)


### goal talking
xyplot(asin(sqrt(goal_talk_prop)) ~ sbaseline_OT|group:gender, type=c("p", "smooth"), data=subset(OT_data, talk_condition=="talk"))

global.model <- lm(asin(sqrt(goal_talk_prop)) ~ (group+gender)*sbaseline_OT,
                     data=subset(OT_data, talk_condition=="talk")) 
summary(global.model)
Anova(global.model, type="II")

        # Model Check
        qqPlot(global.model)
        lillie.test(stdres(global.model))
        xyplot(resid(global.model)~fitted(global.model), type=c("p", "smooth"))  # approx ok
        residualPlots(global.model) # small curvature, but quasi ok
        
plot(effect("group:sbaseline_OT", global.model))

# bootstrap
betahat.boot <- Boot(global.model, R=999) # 199 bootstrap samples--too small to be useful
summary(betahat.boot)  # default summary
confint(betahat.boot)



### baseline OT levels and task talk

xyplot(asin(sqrt(task_talk_prop)) ~ sbaseline_OT|group:gender, type=c("p", "smooth"), data=subset(OT_data, talk_condition=="talk"))

global.model <- lm(asin(sqrt(task_talk_prop)) ~ (group+gender)*sbaseline_OT,
                   data=subset(OT_data, talk_condition=="talk")) 
summary(global.model)
Anova(global.model, type="II")

# Model Check
qqPlot(global.model)
lillie.test(stdres(global.model))
xyplot(resid(global.model)~fitted(global.model), type=c("p", "smooth"))  # approx ok
residualPlots(global.model) # small curvature, but quasi ok

plot(effect("group:sbaseline_OT", global.model))


###  baseline OT levels and other talk

xyplot(asin(sqrt(other_talk_prop)) ~ sbaseline_OT|group:gender, type=c("p", "smooth"), data=subset(OT_data, talk_condition=="talk"))

global.model <- lm(asin(sqrt(other_talk_prop)) ~ (group+gender)*sbaseline_OT,
                   data=subset(OT_data, talk_condition=="talk")) 
summary(global.model)
Anova(global.model, type="II")

# Model Check
qqPlot(global.model)
lillie.test(stdres(global.model))
xyplot(resid(global.model)~fitted(global.model), type=c("p", "smooth"))  # approx ok
residualPlots(global.model) # small curvature, but quasi ok

plot(effect("group:sbaseline_OT", global.model))



##########################################
### change in OT and talk categories #####

## shared intentionality
## scaling the discrete explanatory variables
OT_data$sshared_intentionality_prop <- scale(OT_data$shared_intentionality_prop)
require(mgcv)
xyplot(change_OT ~ sshared_intentionality_prop|group,  type=c("p", "smooth"), data=subset(OT_data, talk_condition=="talk"))
xyplot(change_OT ~ sshared_intentionality_prop|gender, type=c("p", "smooth"), data=subset(OT_data, talk_condition=="talk"))
plot(gam(change_OT ~ s(sshared_intentionality_prop),      data=subset(OT_data, talk_condition=="talk" & group=="InGroup")))
plot(gam(change_OT ~ s(sshared_intentionality_prop),      data=subset(OT_data, talk_condition=="talk" & group=="OutGroup")))
plot(gam(change_OT ~ s(sshared_intentionality_prop, k=4), data=subset(OT_data, talk_condition=="talk" & gender=="male")))
plot(gam(change_OT ~ s(sshared_intentionality_prop),      data=subset(OT_data, talk_condition=="talk" & gender=="female")))

global.model <- lm(change_OT ~ (group+gender)*sshared_intentionality_prop + I(sshared_intentionality_prop^2)
                                  ,na.action=na.exclude, 
                     data=subset(OT_data, talk_condition=="talk"))
summary(global.model)
Anova(global.model, type="II")


      # Model Check
      lillie.test(stdres(global.model))
      qqPlot(global.model)
      residualPlots(global.model)
      xyplot(resid(global.model, type="pearson")~fitted(global.model), type=c("p", "smooth"))  # ok
      influenceIndexPlot(global.model) # approx ok
      
      # bootstrap
      betahat.boot <- Boot(global.model, R=999) 
      summary(betahat.boot)  # default summary
      confint(betahat.boot)



##goal talking


xyplot(change_OT ~ sgoal_talk_prop|group:gender,  type=c("p", "smooth"), data=subset(OT_data, talk_condition=="talk"))

global.model <- lm(change_OT~(group+gender)*sgoal_talk_prop 
                      ,na.action=na.exclude, 
                     data=subset(OT_data, talk_condition=="talk"))

summary(global.model)
Anova(global.model)


        # Model Check
        lillie.test(stdres(global.model))
        qqPlot(global.model, id.n=2)
        plot(global.model, which=1)  # extreme observations
        plot(global.model, which=5)
        xyplot(resid(global.model, type="pearson")~fitted(global.model), type=c("p", "smooth"))  #  ok
        residualPlots(global.model)
    # plot effect
        plot(effect("group:sgoal_talk_prop", global.model))
        plot(effect("gender:sgoal_talk_prop", global.model))
  # bootstrap
        betahat.boot <- Boot(global.model, R=999) # 199 bootstrap samples--too small to be useful
        summary(betahat.boot)  # default summary
        confint(betahat.boot)   

        
        
## task talk

        require(mgcv)
        xyplot(change_OT ~ stask_talk_prop|group,  type=c("p", "smooth"), data=subset(OT_data, talk_condition=="talk"))
        xyplot(change_OT ~ stask_talk_prop|gender, type=c("p", "smooth"), data=subset(OT_data, talk_condition=="talk"))
        plot(gam(change_OT ~ s(stask_talk_prop),      data=subset(OT_data, talk_condition=="talk" & group=="InGroup")))
        plot(gam(change_OT ~ s(stask_talk_prop),      data=subset(OT_data, talk_condition=="talk" & group=="OutGroup")))
        plot(gam(change_OT ~ s(stask_talk_prop, k=4), data=subset(OT_data, talk_condition=="talk" & gender=="male")))
        plot(gam(change_OT ~ s(stask_talk_prop),      data=subset(OT_data, talk_condition=="talk" & gender=="female")))
        
        global.model <- lm(change_OT ~ (group+gender)*stask_talk_prop + I(stask_talk_prop^2)
                           ,na.action=na.exclude, 
                           data=subset(OT_data, talk_condition=="talk"))
        summary(global.model)
        Anova(global.model, type="II")
        
        
        # Model Check
        lillie.test(stdres(global.model))
        qqPlot(global.model)
        residualPlots(global.model)
        xyplot(resid(global.model, type="pearson")~fitted(global.model), type=c("p", "smooth"))  
        influenceIndexPlot(global.model) 
        
## other talk
        
        require(mgcv)
        xyplot(change_OT ~ sother_talk_prop|group,  type=c("p", "smooth"), data=subset(OT_data, talk_condition=="talk"))
        xyplot(change_OT ~ sother_talk_prop|gender, type=c("p", "smooth"), data=subset(OT_data, talk_condition=="talk"))
        plot(gam(change_OT ~ s(sother_talk_prop),      data=subset(OT_data, talk_condition=="talk" & group=="InGroup")))
        plot(gam(change_OT ~ s(sother_talk_prop),      data=subset(OT_data, talk_condition=="talk" & group=="OutGroup")))
        plot(gam(change_OT ~ s(sother_talk_prop, k=4), data=subset(OT_data, talk_condition=="talk" & gender=="male")))
        plot(gam(change_OT ~ s(sother_talk_prop),      data=subset(OT_data, talk_condition=="talk" & gender=="female")))
        
        global.model <- lm(change_OT ~ (group+gender)*sother_talk_prop + I(sother_talk_prop^2)
                           ,na.action=na.exclude, 
                           data=subset(OT_data, talk_condition=="talk"))
        summary(global.model)
        Anova(global.model, type="II")
        
        
        # Model Check
        lillie.test(stdres(global.model))
        qqPlot(global.model)
        residualPlots(global.model)
        xyplot(resid(global.model, type="pearson")~fitted(global.model), type=c("p", "smooth"))  # ok
        influenceIndexPlot(global.model) # approx ok
 
        
########################################################################################################        
### supplementary Analyses from all samples and for other talk categories for all and matched samples ###############################

## Complementary analyses on baseline OT from all the participants (all data)
        
############# baseline OT  and cooperation ###############
        
OT_all<- read.table("OT_data_all.csv")
OT_all <- subset(OT_all, order=="before")
        
        
## scaling the discrete explanatory variables
OT_all$sbaseline_OT <- scale(OT_all$OT)

        
        
        xtabs(~cooperation_binary+group, data=OT_all)
        xtabs(~experiment_ID+group, data=OT_all)
        
        
        global.model <- glm(cooperation_binary ~ (group + gender)*sbaseline_OT+group:gender, 
                            data=OT_all, family=binomial)
        global.model0 <- glm(cooperation_binary ~ 1, data=OT_all, family=binomial)
        
        summary(global.model)
        anova(global.model0, global.model, test="Chi")
        Anova(global.model)
        1-(62.484/83.759)
        
        
        
        # Model Check
        qqPlot(residuals(global.model, "deviance"), id.n=4) # ok 
        plot(residuals(global.model,  "deviance"))
        plot(residuals(global.model,  "deviance") ~ fitted(global.model)) # ok
        residualPlots(global.model) # ok
        
        
        
        # plot effects
        plot(effect("group:sbaseline_OT", global.model))
        
        
        # bootstrap
        betahat.boot <- Boot(global.model, R=999) # 199 bootstrap samples--too small to be useful
        summary(betahat.boot)  # default summary
        confint(betahat.boot)
        
        
### I ## baseline OT levels and shared intentionality
        
        xtabs(~ group + gender, subset(OT_all, talk_condition=="talk"))
        xyplot(asin(sqrt(shared_intentionality_prop)) ~ sbaseline_OT|group:gender, type=c("p", "smooth"), data=subset(OT_all, talk_condition=="talk"))
        
        global.model <- lm(asin(sqrt(shared_intentionality_prop)) ~ (group + gender) * sbaseline_OT +  I(sbaseline_OT^2),
                           data=subset(OT_all, talk_condition=="talk")) 
        summary(global.model)
        Anova(global.model, type="II")
        
        
        # Model Check
        qqPlot(global.model)
        lillie.test(stdres(global.model))
        xyplot(resid(global.model)~fitted(global.model), type=c("p", "smooth"))  # approx ok!! 
        xyplot(resid(global.model)~subset(OT_all, talk_condition=="talk")$sbaseline_OT , type=c("p", "smooth")) # ok
        residualPlots(global.model) #  ok

      
### II ## baseline OT levels and individual goal talk
        
        xyplot(asin(sqrt(goal_talk_prop)) ~ sbaseline_OT|group:gender, type=c("p", "smooth"), data=subset(OT_all, talk_condition=="talk"))
        
        global.model <- lm(asin(sqrt(goal_talk_prop)) ~ (group+gender)*sbaseline_OT,
                           data=subset(OT_all, talk_condition=="talk")) 
        summary(global.model)
        Anova(global.model, type="II")
        
        # Model Check
        qqPlot(global.model)
        lillie.test(stdres(global.model))
        xyplot(resid(global.model)~fitted(global.model), type=c("p", "smooth"))  # approx ok
        residualPlots(global.model) # small curvature, but quasi ok
        
        plot(effect("group:sbaseline_OT", global.model))


### III ## baseline OT levels and task talk
        
        xyplot(asin(sqrt(task_talk_prop)) ~ sbaseline_OT|group:gender, type=c("p", "smooth"), data=subset(OT_all, talk_condition=="talk"))
        
        global.model <- lm(asin(sqrt(task_talk_prop)) ~ (group+gender)*sbaseline_OT,
                           data=subset(OT_all, talk_condition=="talk")) 
        summary(global.model)
        Anova(global.model, type="II")
        
        # Model Check
        qqPlot(global.model)
        lillie.test(stdres(global.model))
        xyplot(resid(global.model)~fitted(global.model), type=c("p", "smooth"))  # approx ok
        residualPlots(global.model) # small curvature, but quasi ok
        
        plot(effect("group:sbaseline_OT", global.model))

### IV ## baseline OT levels and other talk
        
        xyplot(asin(sqrt(other_talk_prop)) ~ sbaseline_OT|group:gender, type=c("p", "smooth"), data=subset(OT_all, talk_condition=="talk"))
        
        global.model <- lm(asin(sqrt(other_talk_prop)) ~ (group+gender)*sbaseline_OT,
                           data=subset(OT_all, talk_condition=="talk")) 
        summary(global.model)
        Anova(global.model, type="II")
        
        # Model Check
        qqPlot(global.model)
        lillie.test(stdres(global.model))
        xyplot(resid(global.model)~fitted(global.model), type=c("p", "smooth"))  # approx ok
        residualPlots(global.model) # small curvature, but quasi ok
        
        plot(effect("group:sbaseline_OT", global.model))

        
############# Active helping and individual goal talking###############
        xtabs(~cooperation_binary+group, data=subset(OT_data, talk_condition=="talk"))
        xtabs(~experiment_ID+group, data=subset(OT_data, talk_condition=="talk"))
        global.model <- glm(cooperation_binary ~  sgoal_talk_prop, 
                            data=subset(OT_data, talk_condition=="talk"), family=binomial)
        global.model0 <- glm(cooperation_binary ~ 1, data=subset(OT_data, talk_condition=="talk"), family=binomial)
        
        summary(global.model)
        anova(global.model0, global.model, test="Chi")
        Anova(global.model)
        1-( 29.019/35.426 )
        
        
        # Model Check
        qqPlot(residuals(global.model, "deviance"), id.n=4) # ok 
        plot(residuals(global.model,  "deviance"))
        plot(residuals(global.model,  "deviance") ~ fitted(global.model)) # ok
        residualPlots(global.model) # ok
        
        
        
        # plot effects
        plot(effect("sgoal_talk_prop", global.model), 
             xlab="Proportion of \n individual goal talk", 
             ylab="Probability of \n costly helping")
        
        
        # bootstrap
        betahat.boot <- Boot(global.model, R=999) # 199 bootstrap samples--too small to be useful
        summary(betahat.boot)  # default summary
        confint(betahat.boot)
        
        
